@@ -38,7 +38,7 @@ get_tree <- function(forest, index) {
     stop(paste("The provided index,", index, "is not valid."))
   }
 
-  # Convert internal grf representation to adjacency list.
+  # Convert internal drf representation to adjacency list.
   # +1 from C++ to R index.
   root <- forest[["_root_nodes"]][[index]] + 1
   left <- forest[["_child_nodes"]][[index]][[1]]
@@ -242,6 +242,12 @@ leaf_stats.drf <- function(forest, samples, ...){
 #'
 #' @return the median heuristic
 medianHeuristic <- function(Y) {
+  
+  # use NROW instead of nrow in case Y is a vector
+  if(NROW(Y) > 5000){
+    rows <- sample(NROW(Y), size = 5000, replace = FALSE, prob = NULL)
+    Y <- Y[rows, ,drop=FALSE]
+  }
   return(stats::median(sqrt(stats::dist(Y)/2)))
 }
 
